@@ -110,10 +110,160 @@ class WebClient(BaseClient):
             "admin.apps.restricted.list", http_verb="GET", params=kwargs
         )
 
-    def admin_conversations_restrictAccess_addGroup(
+    def admin_conversations_create(
+        self, *, is_private: bool, name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Create a public or private channel-based conversation.
+
+        Args:
+            is_private (bool): When true, creates a private channel instead of a public channel
+            name (str): Name of the public or private channel to create.
+            org_wide (bool): When true, the channel will be available org-wide.
+                Note: if the channel is not org_wide=true, you must specify a team_id for this channel
+            team_id (str): The workspace to create the channel in.
+                Note: this argument is required unless you set org_wide=true.
+
+        """
+        kwargs.update({"is_private": is_private, "name": name})
+        return self.api_call("admin.conversations.create", json=kwargs)
+
+    def admin_conversations_delete(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Delete a public or private channel.
+
+        Args:
+            channel_id (str): The channel to delete.
+
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.delete", json=kwargs)
+
+    def admin_conversations_invite(
+        self, *, channel_id: str, user_ids: Union[str, List[str]], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Invite a user to a public or private channel.
+
+        Args:
+            channel_id (str): The channel that the users will be invited to.
+            user_ids (str or list): The users to invite.
+        """
+        kwargs.update({"channel_id": channel_id})
+        if isinstance(user_ids, list):
+            kwargs.update({"user_ids": ",".join(user_ids)})
+        else:
+            kwargs.update({"user_ids": user_ids})
+        # NOTE: the endpoint is unable to handle Content-Type: application/json as of Sep 3, 2020.
+        return self.api_call("admin.conversations.invite", params=kwargs)
+
+    def admin_conversations_archive(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Archive a public or private channel.
+
+        Args:
+            channel_id (str): The channel to archive.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.archive", json=kwargs)
+
+    def admin_conversations_unarchive(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Unarchive a public or private channel.
+
+        Args:
+            channel_id (str): The channel to unarchive.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.unarchive", json=kwargs)
+
+    def admin_conversations_rename(
+        self, *, channel_id: str, name: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Rename a public or private channel.
+
+        Args:
+            channel_id (str): The channel to rename.
+            name (str): The name to rename the channel to.
+        """
+        kwargs.update({"channel_id": channel_id, "name": name})
+        return self.api_call("admin.conversations.rename", json=kwargs)
+
+    def admin_conversations_search(self, **kwargs) -> Union[Future, SlackResponse]:
+        """Search for public or private channels in an Enterprise organization."""
+        return self.api_call("admin.conversations.search", json=kwargs)
+
+    def admin_conversations_convertToPrivate(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Convert a public channel to a private channel.
+
+        Args:
+            channel_id (str): The channel to convert to private.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.convertToPrivate", json=kwargs)
+
+    def admin_conversations_setConversationPrefs(
+        self, *, channel_id: str, prefs: Union[str, dict], **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the posting permissions for a public or private channel.
+
+        Args:
+            channel_id (str): The channel to set the prefs for
+            prefs (str or dict): The prefs for this channel in a stringified JSON format.
+        """
+        kwargs.update({"channel_id": channel_id, "prefs": prefs})
+        return self.api_call("admin.conversations.setConversationPrefs", json=kwargs)
+
+    def admin_conversations_getConversationPrefs(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Get conversation preferences for a public or private channel.
+
+        Args:
+            channel_id (str): The channel to get the preferences for.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.getConversationPrefs", json=kwargs)
+
+    def admin_conversations_disconnectShared(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Disconnect a connected channel from one or more workspaces.
+
+        Args:
+            channel_id (str): The channel to be disconnected from some workspaces.
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.disconnectShared", json=kwargs)
+
+    def admin_conversations_ekm_listOriginalConnectedChannelInfo(
         self, **kwargs
     ) -> Union[Future, SlackResponse]:
-        """Add an allowlist of IDP groups for accessing a channel."""
+        """List all disconnected channels—i.e.,
+        channels that were once connected to other workspaces and then disconnected—and
+        the corresponding original channel IDs for key revocation with EKM.
+        """
+        return self.api_call(
+            "admin.conversations.ekm.listOriginalConnectedChannelInfo", params=kwargs
+        )
+
+    def admin_conversations_restrictAccess_addGroup(
+        self, *, channel_id: str, group_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Add an allowlist of IDP groups for accessing a channel.
+
+        Args:
+            channel_id (str): The channel to link this group to. e.g. 'C1234567890'
+            group_id (str): The IDP Group ID to be an allowlist for the private channel. 'S0604QSJC'
+            team_id (str): The workspace where the channel exists.
+                This argument is required for channels only tied to one workspace,
+                and optional for channels that are shared across an organization.
+                e.g 'T1234'
+        """
+        kwargs.update({"channel_id": channel_id, "group_id": group_id})
         return self.api_call(
             "admin.conversations.restrictAccess.addGroup",
             http_verb="GET",
@@ -121,9 +271,18 @@ class WebClient(BaseClient):
         )
 
     def admin_conversations_restrictAccess_listGroups(
-        self, **kwargs
+        self, *, channel_id: str, **kwargs
     ) -> Union[Future, SlackResponse]:
-        """List all IDP Groups linked to a channel."""
+        """List all IDP Groups linked to a channel.
+
+        Args:
+            channel_id (str): The channel to link this group to. e.g. 'C1234567890'
+            team_id (str): The workspace where the channel exists.
+                This argument is required for channels only tied to one workspace,
+                and optional for channels that are shared across an organization.
+                e.g 'T1234'
+        """
+        kwargs.update({"channel_id": channel_id})
         return self.api_call(
             "admin.conversations.restrictAccess.listGroups",
             http_verb="GET",
@@ -131,19 +290,51 @@ class WebClient(BaseClient):
         )
 
     def admin_conversations_restrictAccess_removeGroup(
-        self, **kwargs
+        self, *, channel_id: str, group_id: str, team_id: str, **kwargs
     ) -> Union[Future, SlackResponse]:
-        """Remove a linked IDP group linked from a private channel."""
+        """Remove a linked IDP group linked from a private channel.
+
+        Args:
+            channel_id (str): The channel to link this group to. e.g. 'C1234567890'
+            group_id (str): The IDP Group ID to be an allowlist for the private channel. 'S0604QSJC'
+            team_id (str): The workspace where the channel exists.
+                This argument is required for channels only tied to one workspace,
+                and optional for channels that are shared across an organization.
+                e.g 'T1234'
+        """
+        kwargs.update(
+            {"channel_id": channel_id, "group_id": group_id, "team_id": team_id}
+        )
         return self.api_call(
             "admin.conversations.restrictAccess.removeGroup",
             http_verb="GET",
             params=kwargs,
         )
 
-    def admin_conversations_setTeams(self, **kwargs) -> Union[Future, SlackResponse]:
-        """Set the workspaces in an Enterprise grid org that connect to a channel."""
+    def admin_conversations_setTeams(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the workspaces in an Enterprise grid org that connect to a channel.
+
+        Args:
+            channel_id (str): The encoded channel_id to add or remove to workspaces.
+
+        """
+        kwargs.update({"channel_id": channel_id})
         return self.api_call("admin.conversations.setTeams", json=kwargs)
 
+    def admin_conversations_getTeams(
+        self, *, channel_id: str, **kwargs
+    ) -> Union[Future, SlackResponse]:
+        """Set the workspaces in an Enterprise grid org that connect to a channel.
+
+        Args:
+            channel_id (str): The channel to determine connected workspaces within the organization for.
+
+        """
+        kwargs.update({"channel_id": channel_id})
+        return self.api_call("admin.conversations.getTeams", json=kwargs)
+
     def admin_emoji_add(self, **kwargs) -> Union[Future, SlackResponse]:
         """Add an emoji."""
         return self.api_call("admin.emoji.add", http_verb="GET", params=kwargs)
@@ -2043,7 +2234,7 @@ class WebClient(BaseClient):
         return self.api_call("views.open", json=kwargs)
 
     def views_push(
-        self, *, trigger_id: str, view: dict, **kwargs
+        self, *, trigger_id: str, view: Union[dict, View], **kwargs
     ) -> Union[Future, SlackResponse]:
         """Push a view onto the stack of a root view.
 
@@ -2057,13 +2248,22 @@ class WebClient(BaseClient):
         Args:
             trigger_id (str): Exchange a trigger to post to the user.
                 e.g. '12345.98765.abcd2358fdea'
-            view (dict): The view payload.
+            view (dict or View): The view payload.
         """
-        kwargs.update({"trigger_id": trigger_id, "view": view})
+        kwargs.update({"trigger_id": trigger_id})
+        if isinstance(view, View):
+            kwargs.update({"view": view.to_dict()})
+        else:
+            kwargs.update({"view": view})
         return self.api_call("views.push", json=kwargs)
 
     def views_update(
-        self, *, view: dict, external_id: str = None, view_id: str = None, **kwargs
+        self,
+        *,
+        view: Union[dict, View],
+        external_id: str = None,
+        view_id: str = None,
+        **kwargs
     ) -> Union[Future, SlackResponse]:
         """Update an existing view.
 
@@ -2074,7 +2274,7 @@ class WebClient(BaseClient):
         to learn more about updating views and avoiding race conditions with the hash argument.
 
         Args:
-            view (dict): The view payload.
+            view (dict or View): The view payload.
             external_id (str): A unique identifier of the view set by the developer.
                 e.g. 'bmarley_view2'
             view_id (str): A unique identifier of the view to be updated.
@@ -2082,7 +2282,6 @@ class WebClient(BaseClient):
         Raises:
             SlackRequestError: Either view_id or external_id is required.
         """
-        kwargs.update({"view": view})
         if external_id:
             kwargs.update({"external_id": external_id})
         elif view_id:
@@ -2090,10 +2289,15 @@ class WebClient(BaseClient):
         else:
             raise e.SlackRequestError("Either view_id or external_id is required.")
 
+        if isinstance(view, View):
+            kwargs.update({"view": view.to_dict()})
+        else:
+            kwargs.update({"view": view})
+
         return self.api_call("views.update", json=kwargs)
 
     def views_publish(
-        self, *, user_id: str, view: dict, **kwargs
+        self, *, user_id: str, view: Union[dict, View], **kwargs
     ) -> Union[Future, SlackResponse]:
         """Publish a static view for a User.
         Create or update the view that comprises an
@@ -2102,7 +2306,11 @@ class WebClient(BaseClient):
         Args:
             user_id (str): id of the user you want publish a view to.
                 e.g. 'U0BPQUNTA'
-            view (dict): The view payload.
+            view (dict or View): The view payload.
         """
-        kwargs.update({"user_id": user_id, "view": view})
+        kwargs.update({"user_id": user_id})
+        if isinstance(view, View):
+            kwargs.update({"view": view.to_dict()})
+        else:
+            kwargs.update({"view": view})
         return self.api_call("views.publish", json=kwargs)
